import { isDateHelperMixin } from './date-helper';
export function isDirectiveOptions(value) {
    return value && value['value'] && (typeof value['value'] === 'string' || value['value'] instanceof Date);
}
var DirectiveHelper = /** @class */ (function () {
    function DirectiveHelper(helper, binding, context, value) {
        this.helper = helper;
        this.original = null;
        this.current = null;
        this.hooks = null;
        this.currentDate = value;
        this.hooks = this.buildHooks(binding, context);
        this.strategy = this.buildUpdateStrategy(binding, context);
    }
    DirectiveHelper.prototype.buildUpdateStrategy = function (binding, context) {
        var data = binding.value;
        if (isDirectiveOptions(data))
            return function (value) {
                context.$set(context, data.value, value);
                context.$emit('input', value);
            };
        else
            return function (value) {
                context[binding.expression] = value;
                context.$emit('input', value);
            };
    };
    DirectiveHelper.prototype.buildHooks = function (binding, context) {
        var map = new Map();
        var data = binding.value;
        if (data) {
            Object.getOwnPropertyNames(data).forEach(function (o) {
                if (isDateHelperMixin(o, typeof data[o]))
                    map.set(o, data[o]);
            });
        }
        return map;
    };
    Object.defineProperty(DirectiveHelper.prototype, "currentDate", {
        get: function () {
            return this.current;
        },
        set: function (value) {
            if (this.original === null)
                this.original = value;
            this.current = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DirectiveHelper.prototype, "pattern", {
        get: function () {
            return this.helper.pattern;
        },
        set: function (value) {
            this.helper.pattern = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DirectiveHelper.prototype, "originalDate", {
        get: function () {
            return this.original;
        },
        enumerable: true,
        configurable: true
    });
    DirectiveHelper.prototype.adjustDate = function (leftDate, rightDate) {
        if (this.hooks.has('adjustDate'))
            return this.hooks.get('adjustDate').apply(leftDate, rightDate);
        else
            return this.helper.adjustDate(leftDate, rightDate);
    };
    DirectiveHelper.prototype.equal = function (leftDate, rightDate) {
        if (this.hooks.has('equal'))
            return this.hooks.get('equal').apply(leftDate, rightDate);
        else
            return this.helper.equal(leftDate, rightDate);
    };
    DirectiveHelper.prototype.format = function (value, pattern) {
        if (this.hooks.has('format'))
            return this.hooks.get('format').apply(value, pattern);
        else
            return this.helper.format(value, pattern);
    };
    DirectiveHelper.prototype.parse = function (value, pattern) {
        if (this.hooks.has('parse'))
            return this.hooks.get('parse').apply(value, pattern);
        else
            return this.helper.parse(value, pattern);
    };
    Object.defineProperty(DirectiveHelper.prototype, "updateModel", {
        get: function () {
            return this.strategy;
        },
        enumerable: true,
        configurable: true
    });
    return DirectiveHelper;
}());
export { DirectiveHelper };
;
export default DirectiveHelper;
//# sourceMappingURL=directive-helper.js.map