"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_formatter_1 = require("./date-fns-formatter");
var directive_helper_1 = require("./directive-helper");
function createHelper(el, binding, vnode) {
    var helper = null;
    var defaultFormatString = 'YYYY-MM-DD';
    if (el.tagName.toLowerCase() === 'input' && el.type.toLowerCase() === 'date' || el.type.toLowerCase() === 'text') {
        var data = binding.value;
        var formatter = new date_fns_formatter_1.DateFnsFormatter(defaultFormatString);
        if (!data) {
            helper = new directive_helper_1.DirectiveHelper(formatter, binding, vnode.context, null);
        }
        else if (directive_helper_1.isDirectiveOptions(data)) {
            var value = typeof data.value === 'string' ? vnode.context[data.value] : data.value;
            if (el.type.toLowerCase() === 'text' && data.pattern)
                formatter = new date_fns_formatter_1.DateFnsFormatter(data.pattern);
            helper = new directive_helper_1.DirectiveHelper(formatter, binding, vnode.context, value);
        }
        else if (data instanceof Date) {
            helper = new directive_helper_1.DirectiveHelper(formatter, binding, vnode.context, data);
        }
        else if (typeof data === 'string') {
            helper = new directive_helper_1.DirectiveHelper(formatter, binding, vnode.context, formatter.parse(data));
        }
    }
    else {
        emitWarning('can only bind to input elements of type= \'date\' or \'text\'');
    }
    return helper;
}
function createOptions() {
    var helper = null;
    var inserted = function (el, binding, vnode, oldVnode) {
        var helper = createHelper(el, binding, vnode);
        if (helper !== null) {
            var context = vnode.context;
            var expression = binding.expression;
            if (helper.currentDate) {
                el.value = helper.format(helper.currentDate);
                el.valueAsDate = helper.currentDate;
            }
            el.dataset.hasNativeSupport = hasNativeSupport() ? '0' : '1';
            el.addEventListener('change', function ($event) {
                var value = $event.target.value;
                if (value) {
                    var date = helper.adjustDate(helper.parse(value), helper.currentDate);
                    if (date && !helper.equal(helper.currentDate, date))
                        helper.updateModel(date);
                }
                else if (value === '') {
                    helper.updateModel(null);
                }
            });
        }
    };
    return {
        inserted: inserted
    };
}
function emitWarning(msg) {
    console.warn('vue-model-date:' + msg.trim());
}
function hasNativeSupport() {
    var test = document.createElement('input');
    test.type = 'date';
    return test.type !== 'text';
}
var date_helper_1 = require("./date-helper");
exports.VueModelDateHooks = date_helper_1.DateHelperHooks;
exports.VueModelDate = createOptions();
exports.default = exports.VueModelDate;
//# sourceMappingURL=index.js.map